<?php

/**
 *	
 */


require_once ('../require.php');

$parms = array (

		"DNS"           =>PDO_DNS ,
		"user"          =>PDO_USER ,
		"password"      =>PDO_PASS,
		"table"         =>'person',
		"userid"        =>$_POST['id'],
		"userpass"      =>$_POST['pass'],

	       );

if(isset($_POST['id'])) {
	$session = new Mysession_db("DB",$parms,false);
} else {
	$session = new Mysession_db("CONTINUE",$parms,false);
}



//セッションが始まったら他のページに飛ぶ



$session->start();


if($_SESSION['tiket']==SESSIONPASS){
	header("Location:http://localhost". $_GET['continue']);
	exit;
}       else {

	$smarty->assign("loginerr",$session->geterrmsg());
}


$smarty->assign("title","ログイン認証"); //headerのtitle
$smarty->assign("pagename","login");
/*
   if($_POST['flag'] == "index") { 
   $smarty->display("index.tpl");

   } elseif ($_POST['flag'] == "rental") {
   $smarty->display("borrow_confirm.tpl");

   } else {
   $smarty->display("login.tpl");
   }
*/

$smarty->display("login.tpl");


?>
